# wordle-mini
wordle in the command-line with Textual

<div align="center">

![wordle preview image](https://github.com/user-attachments/assets/d4ab46ef-8787-4aae-80d7-8b0a6a5bc7e8)
![licence](https://img.shields.io/badge/licence-MIT-green?style=flat?logo=licence)
[![PyPI version](https://img.shields.io/pypi/v/wordlemini?style=flat-square)](https://pypi.org/project/wordlemini/)
[![Publish to PyPI.org](https://github.com/tomasvana10/wordlemini/actions/workflows/publish.yml/badge.svg)](https://github.com/tomasvana10/wordlemini/actions/workflows/publish.yml)
[![release](https://img.shields.io/github/v/release/tomasvana10/wordlemini?logo=github)](https://github.com/tomasvana10/wordlemini/releases/latest)
[![issues](https://img.shields.io/github/issues-raw/tomasvana10/wordlemini.svg?maxAge=25000)](https://github.com/tomasvana10/wordlemini/issues)
[![CodeQL](https://github.com/tomasvana10/wordlemini/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/tomasvana10/wordlemini/actions/workflows/github-code-scanning/codeql)
[![Tests](https://github.com/tomasvana10/wordlemini/actions/workflows/tox-tests.yml/badge.svg)](https://github.com/tomasvana10/wordlemini/actions/workflows/tox-tests.yml)

</div>

### Installation
Install the package from PyPI:
```
pip install wordlemini
```

Run the game:
```
wordlemini
```

### Runtime dependencies
`textual`

### Acknowledgements
[textual](https://textual.textualize.io/) - A Rapid Application Development framework for Python, built by Textualize.io.
